pub struct SignalSeparator { /* private fields */ }Expand description
Signal separator that applies the coherence analysis to split signals.
Implementations
Sourceimpl SignalSeparator
impl SignalSeparator
Sourcepub fn new(config: SeparationConfig) -> Self
pub fn new(config: SeparationConfig) -> Self
Create a new signal separator.
Sourcepub fn separate(&self, value: Complex, coherence: f32) -> (Complex, Complex)
pub fn separate(&self, value: Complex, coherence: f32) -> (Complex, Complex)
Separate a complex value into direct and ambient components.
Sourcepub fn separate_with_frequency(
&self,
value: Complex,
coherence: f32,
bin_index: u32,
total_bins: u32,
) -> (Complex, Complex)
pub fn separate_with_frequency( &self, value: Complex, coherence: f32, bin_index: u32, total_bins: u32, ) -> (Complex, Complex)
Separate with frequency-dependent adjustment.
Sourcepub fn config(&self) -> &SeparationConfig
pub fn config(&self) -> &SeparationConfig
Get configuration.
Sourcepub fn set_config(&mut self, config: SeparationConfig)
pub fn set_config(&mut self, config: SeparationConfig)
Update configuration.